/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef CAMERACONFIG_H_286764653__H_
#define CAMERACONFIG_H_286764653__H_


#include <boost/any.hpp>
#include <avro/Specific.hh>
#include <avro/Encoder.hh>
#include <avro/Decoder.hh>
struct CameraConfig {
    std::string brokerAddress;
    std::string connectionOptions;
    std::string destination;
    int32_t cameraNumber;
    int32_t frameLength;
    int32_t imageWidth;
    int32_t imageHeight;
    int32_t imageChannels;
};

namespace avro {
template<> struct codec_traits<CameraConfig> {
    static void encode(Encoder& e, const CameraConfig& v) {
        avro::encode(e, v.brokerAddress);
        avro::encode(e, v.connectionOptions);
        avro::encode(e, v.destination);
        avro::encode(e, v.cameraNumber);
        avro::encode(e, v.frameLength);
        avro::encode(e, v.imageWidth);
        avro::encode(e, v.imageHeight);
        avro::encode(e, v.imageChannels);
    }
    static void decode(Decoder& d, CameraConfig& v) {
        avro::decode(d, v.brokerAddress);
        avro::decode(d, v.connectionOptions);
        avro::decode(d, v.destination);
        avro::decode(d, v.cameraNumber);
        avro::decode(d, v.frameLength);
        avro::decode(d, v.imageWidth);
        avro::decode(d, v.imageHeight);
        avro::decode(d, v.imageChannels);
    }
};

}
#endif
