/* 
 * File:   main.cpp
 * Author: matt
 *
 * Created on November 12, 2011, 4:06 PM
 */

#include "robokind/messaging/AQStream.h"
#include "robokind/messaging/AQSender.h"
#include "robokind/messaging/AQService.h"
#include "robokind/messaging/AQServiceProvider.h"
#include "robokind/vision/camera/CameraService.h"
#include "robokind/vision/camera/protocol/CameraConfig.h"

using namespace std;
using namespace qpid::messaging;
using namespace robokind;

const char* connectionStr = "localhost:5672";
const char* connectionOpt = "{username:admin,password:admin}";
const char* destVidQ = "vision.VideoTopic1; {create: always, node: {type: topic}}";
const char* destCamCmd = "vision.CamCmdQueue1; {create: always, node: {type: queue}}";
const char* destCamErr = "vision.CamErrQueue1; {create: always, node: {type: queue}}";

CameraConfig* getDefaultCameraConfig(){
	CameraConfig* conf = new CameraConfig();
    conf->brokerAddress = connectionStr;
    conf->connectionOptions = connectionOpt;
    conf->destination = destVidQ;
    conf->cameraNumber = 0;
    conf->frameLength = 100;
    conf->imageChannels = 1;
    conf->imageWidth = 320;
    conf->imageHeight = 240;
    return conf;
}

template<typename T> void provider(AQService<T>* service, const char* destCmd, const char* destErr){
    AQStream* myStream;
    myStream = new AQStream();
    if(!myStream->connect())
        return;
    AQReceiver* cmdRec = myStream->createReceiver(destCmd);
    AQSender* errSnd = myStream->createSender(destErr);
    AQServiceProvider<T> s(service, cmdRec, errSnd);
    s.start();
}

int main(int argc, char** argv) {
    cout << "Creating Camera Capture Service." << endl;
	CameraService* service = new CameraService();
	CameraConfig* config;
	if(argc <= 1){
		cout << "No file specified, loading default config." << endl;
		config = getDefaultCameraConfig();
	}else{
		config = loadFromFile<CameraConfig>(argv[1]);
	}
	if(config != NULL){
		service->initialize(config);
	}
    provider<CameraConfig>(service, destCamCmd, destCamErr);
    return 0;
}

