#include <iostream>
#include "robokind/messaging/AQStream.h"
#include "robokind/messaging/AQSender.h"
#include "robokind/messaging/AQService.h"
#include "robokind/messaging/AQServiceProvider.h"
#include "robokind/speech/SpeechEngine.h"
#include "robokind/speech/SpeechService.h"
#include "robokind/speech/mssapi/SAPIEngine.h"
#include "robokind/speech/protocol/SpeechConfigRecord.h"
#include "robokind/speech/protocol/SpeechRequestRecord.h"
#include "robokind/speech/protocol/SpeechEventListRecord.h"
#include "robokind/speech/protocol/SpeechEventRecord.h"

using namespace std;
using namespace qpid::messaging;
using namespace robokind;
using namespace robokind::speech;

const char* connectionStr = "localhost:5672";
const char* connectionOpt = "{username:admin,password:admin}";
const char* requestQueue = "speech.RequestQueue1; {create: always, node: {type: queue}}";
const char* eventQueue = "speech.EventQueue1; {create: always, node: {type: queue}}";
const char* cmdQueue = "speech.CommandQueue1; {create: always, node: {type: queue}}";
const char* errQueue = "speech.ErrorQueue1; {create: always, node: {type: queue}}";

void sendCmd(AQSender* sender, ServiceCommand sc){
    AQServiceCommand cmd;
    cmd.command = sc;
    sender->send<AQServiceCommand>(&cmd, "application/service-command", true);
}

void sending(AQSender* cmdSender, AQSender* reqSender){
    while(1){
		cout << "Enter a phrase (:q to quit): ";
        char *cmd = new char[256];
        cin.getline(cmd, 255);
        if(strncmp(cmd, ":q", 3) == 0){
			sendCmd(cmdSender, STOP);
            return;
        }else if(strncmp(cmd, ":p", 3) == 0){
            sendCmd(cmdSender, PAUSE);
            continue;
        }else if(strncmp(cmd, ":r", 3) == 0){
            sendCmd(cmdSender, RESUME);
            continue;
        }
        SpeechRequestRecord* req = new SpeechRequestRecord();
        req->phrase.assign(cmd);
		req->requestSourceId.assign("");
		req->speechServiceId.assign("");
		req->timestampMillisecUTC = 0;
        reqSender->send<SpeechRequestRecord>(req);
    }
}

void receiving(){
    AQStream* aqs = new AQStream();
    aqs->connect();
    AQReceiver* receiver = aqs->createReceiver(eventQueue);
    while(1){
        SpeechEventListRecord* e = receiver->fetch<SpeechEventListRecord>();
		cout << "event: " << e->speechServiceId << endl;
    }
}

int main(int argc, char **argv) {
    AQStream* aqs = new AQStream();
    aqs->connect();
    AQSender* sender = aqs->createSender(cmdQueue);
    sendCmd(sender, START);
    sending(sender, aqs->createSender(requestQueue));
    return 0;
}

